==> apache-iceberg-0.14.1.tar.gz: apache-iceberg-0.14.1/flink/v1.14/flink/src/test/java/org/apache/iceberg/flink/source/enumerator/ManualContinuousSplitPlanner.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg.flink.source.enumerator;

import java.io.IOException;
import java.util.ArrayDeque;
import java.util.List;
import org.apache.iceberg.flink.source.split.IcebergSourceSplit;
import org.apache.iceberg.relocated.com.google.common.collect.Lists;

class ManualContinuousSplitPlanner implements ContinuousSplitPlanner {
  private final ArrayDeque<IcebergSourceSplit> splits = new ArrayDeque<>();
  private IcebergEnumeratorPosition latestPosition;

  @Override
  public ContinuousEnumerationResult planSplits(IcebergEnumeratorPosition lastPosition) {
    ContinuousEnumerationResult result = new ContinuousEnumerationResult(
        Lists.newArrayList(splits), lastPosition, latestPosition);
    return result;
  }

  /**
   * Add new splits to the collection
   */
  public void addSplits(List<IcebergSourceSplit> newSplits, IcebergEnumeratorPosition newPosition) {
    splits.addAll(newSplits);
    this.latestPosition = newPosition;
  }

  /**
   * Clear the splits collection
   */
  public void clearSplits() {
    splits.clear();
  }

  @Override
  public void close() throws IOException {
  }
}

==> apache-iceberg-1.1.0.tar.gz: apache-iceberg-1.1.0/flink/v1.16/flink/src/test/java/org/apache/iceberg/flink/source/enumerator/ManualContinuousSplitPlanner.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.flink.source.enumerator;

import java.io.IOException;
import java.util.ArrayDeque;
import java.util.List;
import org.apache.iceberg.flink.source.split.IcebergSourceSplit;
import org.apache.iceberg.relocated.com.google.common.collect.Lists;

class ManualContinuousSplitPlanner implements ContinuousSplitPlanner {
  private final ArrayDeque<IcebergSourceSplit> splits = new ArrayDeque<>();
  private IcebergEnumeratorPosition latestPosition;

  @Override
  public ContinuousEnumerationResult planSplits(IcebergEnumeratorPosition lastPosition) {
    ContinuousEnumerationResult result =
        new ContinuousEnumerationResult(Lists.newArrayList(splits), lastPosition, latestPosition);
    return result;
  }

  /** Add new splits to the collection */
  public void addSplits(List<IcebergSourceSplit> newSplits, IcebergEnumeratorPosition newPosition) {
    splits.addAll(newSplits);
    this.latestPosition = newPosition;
  }

  /** Clear the splits collection */
  public void clearSplits() {
    splits.clear();
  }

  @Override
  public void close() throws IOException {}
}
